@@ -1,5 +1,5 @@
 /* Test of character set conversion with error handling.
-   Copyright (C) 2007-2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* Written by Bruno Haible <bruno@clisp.org>, 2007.  */
 
@@ -496,6 +496,9 @@ main ()
           free (result);
         }
 
+      /* Disabled on NetBSD, because NetBSD 5.0 iconv() is buggy: it converts
+         the input "+2D/YQNhB" to U+1FED8 U+3FD8 U+40D8.  */
+#  if !(defined __NetBSD__ && !defined _LIBICONV_VERSION)
       /* Test conversion from UTF-7 to UTF-8 with EILSEQ.  */
       for (h = 0; h < SIZEOF (handlers); h++)
         {
@@ -543,6 +546,7 @@ main ()
               break;
             }
         }
+#  endif
 # endif
     }
 
