@@ -1,5 +1,5 @@
 /* Test of u32_prev() function.
-   Copyright (C) 2010-2015 Free Software Foundation, Inc.
+   Copyright (C) 2010-2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* Written by Bruno Haible <bruno@clisp.org>, 2010.  */
 
@@ -56,7 +56,6 @@ check (const uint32_t *input, size_t input_length, ucs4_t *puc)
 static int
 check_invalid (const uint32_t *input, size_t input_length)
 {
-#if CONFIG_UNICODE_SAFETY
   ucs4_t uc;
 
   /* Test recognition when at the beginning of the string.  */
@@ -83,7 +82,6 @@ check_invalid (const uint32_t *input, size_t input_length)
     if (uc != 0xBADFACE)
       return 4;
   }
-#endif
 
   return 0;
 }
